@@ -42,6 +42,7 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
+#include "gnome-settings-profile.h"
 #include "gsd-marshal.h"
 #include "gsd-media-keys-manager.h"
 #include "gsd-media-keys-manager-glue.h"
@@ -62,7 +63,7 @@
    these modifiers mean
    these are the mods whose combinations are bound by the keygrabbing code */
 #define IGNORED_MODS (0x2000 /*Xkb modifier*/ | GDK_LOCK_MASK  | \
-	GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK | GDK_MOD5_MASK)
+       GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK | GDK_MOD5_MASK)
 /* these are the ones we actually use for global keys, we always only check
  * for these set */
 #define USED_MODS (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)
@@ -281,6 +282,7 @@ grab_key_real (Key       *key,
 {
         gdk_error_trap_push ();
         if (grab) {
+                g_debug ("Grab: %d %d %x %s", result, (int)key->keycode, key->state, XKeysymToString (key->keysym));
                 XGrabKey (GDK_DISPLAY (),
                           key->keycode,
                           (result | key->state),
@@ -289,6 +291,7 @@ grab_key_real (Key       *key,
                           GrabModeAsync,
                           GrabModeAsync);
         } else {
+                g_debug ("UnGrab: %d %d %x", result, (int)key->keycode, key->state);
                 XUngrabKey (GDK_DISPLAY (),
                             key->keycode,
                             (result | key->state),
@@ -419,6 +422,8 @@ init_kbd (GsdMediaKeysManager *manager)
 {
         int i;
 
+        gnome_settings_profile_start (NULL);
+
         for (i = 0; i < HANDLED_KEYS; i++) {
                 char *tmp;
                 Key  *key;
@@ -434,6 +439,7 @@ init_kbd (GsdMediaKeysManager *manager)
                                                keys[i].gconf_key,
                                                NULL);
                 if (!is_valid_shortcut (tmp)) {
+                        g_debug ("Not a valid shortcut: '%s'", tmp);
                         g_free (tmp);
                         continue;
                 }
@@ -441,6 +447,8 @@ init_kbd (GsdMediaKeysManager *manager)
                 key = g_new0 (Key, 1);
                 if (!egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycode, &key->state)
                     || key->keycode == 0) {
+                        g_debug ("Unable to parse: '%s'", tmp);
+
                         g_free (tmp);
                         g_free (key);
                         continue;
@@ -459,6 +467,8 @@ init_kbd (GsdMediaKeysManager *manager)
 
                 grab_key (manager, key, TRUE);
         }
+
+        gnome_settings_profile_end (NULL);
 }
 
 static void
@@ -845,7 +855,7 @@ do_action (GsdMediaKeysManager *manager,
                 break;
         case HOME_KEY:
                 path = g_shell_quote (g_get_home_dir ());
-                cmd = g_strconcat ("nautilus --no-desktop", path, NULL);
+                cmd = g_strconcat ("nautilus --no-desktop ", path, NULL);
                 g_free (path);
                 execute (manager, cmd, FALSE, FALSE);
                 g_free (cmd);
@@ -992,7 +1002,7 @@ gsd_media_keys_manager_start (GsdMediaKeysManager *manager,
         GSList *l;
 
         g_debug ("Starting media_keys manager");
-
+        gnome_settings_profile_start (NULL);
         manager->priv->conf_client = gconf_client_get_default ();
 
         gconf_client_add_dir (manager->priv->conf_client,
@@ -1004,15 +1014,25 @@ gsd_media_keys_manager_start (GsdMediaKeysManager *manager,
         init_kbd (manager);
 
         /* initialise Volume handler */
+        gnome_settings_profile_start ("acme_volume_new");
         manager->priv->volume = acme_volume_new ();
+        gnome_settings_profile_end ("acme_volume_new");
 
         /* Start filtering the events */
         for (l = manager->priv->screens; l != NULL; l = l->next) {
+                gnome_settings_profile_start ("gdk_window_add_filter");
+
+                g_debug ("adding key filter for screen: %d",
+                         gdk_screen_get_number (l->data));
+
                 gdk_window_add_filter (gdk_screen_get_root_window (l->data),
                                        (GdkFilterFunc)acme_filter_events,
                                        manager);
+                gnome_settings_profile_end ("gdk_window_add_filter");
         }
 
+        gnome_settings_profile_end (NULL);
+
         return TRUE;
 }
 
